package edu.kit.ipd.descartes.adaptation.model.perfdatarepo;

import java.util.List;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.util.EcoreUtil;

import edu.kit.ipd.descartes.mm.adaptation.WeightedTactic;
import edu.kit.ipd.descartes.ql.models.repository.ObservableImpact;
import edu.kit.ipd.descartes.ql.models.repository.Observation;
import edu.kit.ipd.descartes.ql.models.repository.ObservationRepository;


public class ObservationRepositoryHelper {

    public static ObservableImpact searchImpactOfTactic(String name, String modelUri) {
        ObservationRepositoryModelLoader loader = ObservationRepositoryModelLoader.getInstance();
        ObservationRepository repo = (ObservationRepository) loader.load(URI.createFileURI(modelUri));

        // Get correct result
        Observation o = getResultEndingWith(name, repo);
        
        // Derive impact from result
        ObservableImpact i = deriveImpact(o, repo);
        return i;
    }


    public static String deriveExperimentName(WeightedTactic tactic) {
        return tactic.getName();
    }


    private static ObservableImpact deriveImpact(Observation o, ObservationRepository repo) {
        List<ObservableImpact> impacts = repo.getImpacts();
        for (ObservableImpact oi : impacts) {
            if (EcoreUtil.equals(oi.getAfter(), o))
                return oi;
        }
        
        return null;
    }


    /** 
     * Searches the observation repository for an observation that ends with the given 
     * suffix.
     * 
     * @param suffix
     * @return first result that ends the given suffix, null otherwise.
     */
    public static Observation getResultEndingWith(String suffix, ObservationRepository repo) {
        List<Observation> results = repo.getObservations();
        for (Observation o : results) {
            if(o.getIdentifier().endsWith(suffix))
                return o;
        }
        return null;
    }


}
